import requests
from bs4 import BeautifulSoup

WOGETRA_URL = "https://www.wogetra.de/immobilien-vermarktungsart/miete/"

def find_property(details, property):
    prop = "N/A"
    if details:
        prop_row = details.find("div", class_=property)
        if prop_row:
            dd = prop_row.find("div", class_="dd")
            if dd:
                prop = dd.text.strip()
    return prop


# Funktion: Scrape von Wogetra
def scrape_wogetra():
    response = requests.get(WOGETRA_URL)
    soup = BeautifulSoup(response.content, 'html.parser')

    # Find all property containers
    property_elements = soup.find_all("div", class_="property-container")
    properties = []

    for prop in property_elements:
        # Extract property details
        title_element = prop.find("h3", class_="property-title")
        subtitle_element = prop.find("div", class_="property-subtitle")
        link_element = title_element.find("a") if title_element else None

        details = prop.find("div", class_="property-data")

        # Extract details (ID, rooms, size, etc.)
        property_id = prop.get("id", "")
        title = title_element.text.strip() if title_element else "No Title"
        subtitle = subtitle_element.text.strip() if subtitle_element else "No Subtitle"
        link = link_element["href"] if link_element else "#"

        # Extract specific details
        rooms = find_property(details, "data-anzahl_zimmer")
        size = find_property(details, "data-wohnflaeche")
        rent = find_property(details, "data-nettokaltmiete")
        warm_rent = find_property(details, "data-warmmiete")
        availability = find_property(details, "data-verfuegbar_ab")

        # Add property to list
        properties.append({
            "id": property_id,
            "title": "Wogetra - "+ title,
            "subtitle": subtitle,
            "rooms": rooms,
            "size": size,
            "rent": rent,
            "link": link,
            "abstract": "",
            "warm_rent": warm_rent,
            "availability": availability,
            "image_url": "",
        })

    return properties